<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>CardWidget</name>
    <message>
        <location filename="../../cardwidget.ui" line="14"/>
        <source>Form</source>
        <translation>形式</translation>
    </message>
    <message>
        <location filename="../../cardwidget.ui" line="29"/>
        <source>Card Name</source>
        <translation>声卡名称</translation>
    </message>
    <message>
        <location filename="../../cardwidget.ui" line="38"/>
        <source>Profile:</source>
        <translation>配置方案:</translation>
    </message>
    <message>
        <location filename="../../cardwidget.cc" line="66"/>
        <source>pa_context_set_card_profile_by_index() failed</source>
        <translation>pa_context_set_card_profile_by_index() 失败</translation>
    </message>
</context>
<context>
    <name>Channel</name>
    <message>
        <location filename="../../channel.cc" line="89"/>
        <source>%1% (%2dB)</source>
        <comment>volume slider label [X% (YdB)]</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../../channel.cc" line="93"/>
        <source>%1%</source>
        <comment>volume slider label [X%]</comment>
        <translation></translation>
    </message>
    <message>
        <location filename="../../channel.cc" line="160"/>
        <source>&lt;small&gt;Silence&lt;/small&gt;</source>
        <translation>&lt;small&gt;安静&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../../channel.cc" line="160"/>
        <source>&lt;small&gt;Min&lt;/small&gt;</source>
        <translation>&lt;small&gt;最小&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../../channel.cc" line="162"/>
        <source>&lt;small&gt;100% (0dB)&lt;/small&gt;</source>
        <translation>&lt;small&gt;100% (0dB)&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../../channel.cc" line="165"/>
        <source>&lt;small&gt;&lt;i&gt;Base&lt;/i&gt;&lt;/small&gt;</source>
        <translation>&lt;small&gt;&lt;i&gt;基本&lt;/i&gt;&lt;/small&gt;</translation>
    </message>
</context>
<context>
    <name>ChannelWidget</name>
    <message>
        <source>&lt;b&gt;left-front&lt;/b&gt;</source>
        <translation type="vanished">&lt;b&gt;左-前&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>DeviceWidget</name>
    <message>
        <location filename="../../devicewidget.ui" line="14"/>
        <source>Form</source>
        <translation>形式</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="36"/>
        <source>Device Title</source>
        <translation>设备标题</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="56"/>
        <source>Mute audio</source>
        <translation>静音</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="69"/>
        <source>Lock channels together</source>
        <translation>同时设置声道</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="85"/>
        <source>Set as fallback</source>
        <translation>设置为默认</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="103"/>
        <source>&lt;b&gt;Port:&lt;/b&gt;</source>
        <translation>&lt;b&gt;端口:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="126"/>
        <source>Show advanced options</source>
        <translation>显示高级选项</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="172"/>
        <source>PCM</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="182"/>
        <source>AC3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="189"/>
        <source>EAC3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="196"/>
        <source>DTS</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="203"/>
        <source>MPEG</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="210"/>
        <source>AAC</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="238"/>
        <source>&lt;b&gt;Latency offset:&lt;/b&gt;</source>
        <translation>&lt;b&gt;延迟补偿:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="245"/>
        <source> ms</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../devicewidget.cc" line="40"/>
        <source>Rename device...</source>
        <translation>重命名设备...</translation>
    </message>
    <message>
        <location filename="../../devicewidget.cc" line="154"/>
        <source>pa_context_set_port_latency_offset() failed</source>
        <translation>pa_context_set_port_latency_offset() 失败</translation>
    </message>
    <message>
        <location filename="../../devicewidget.cc" line="225"/>
        <source>Sorry, but device renaming is not supported.</source>
        <translation>抱歉，不支持设备重命名。</translation>
    </message>
    <message>
        <location filename="../../devicewidget.cc" line="226"/>
        <source>You need to load module-device-manager in the PulseAudio server in order to rename devices</source>
        <translation>要重命名设备，您需要在 PulseAudio 服务器中加载模块设备管理器</translation>
    </message>
    <message>
        <location filename="../../devicewidget.cc" line="232"/>
        <source>Rename device %1 to:</source>
        <translation>重命名设备 %1 为:</translation>
    </message>
    <message>
        <location filename="../../devicewidget.cc" line="239"/>
        <source>pa_ext_device_manager_set_device_description() failed</source>
        <translation>pa_ext_device_manager_set_device_description() 失败</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../mainwindow.ui" line="14"/>
        <source>Volume Control</source>
        <translation>音量控制</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="28"/>
        <source>&amp;Playback</source>
        <translation>回放(&amp;P)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="55"/>
        <source>&lt;i&gt;No application is currently playing audio.&lt;/i&gt;</source>
        <translation>&lt;i&gt;没有程序正在播放音频。&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="66"/>
        <location filename="../../mainwindow.ui" line="131"/>
        <location filename="../../mainwindow.ui" line="196"/>
        <location filename="../../mainwindow.ui" line="261"/>
        <source>Show:</source>
        <translation>显示:</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="74"/>
        <location filename="../../mainwindow.ui" line="139"/>
        <source>All Streams</source>
        <translation>所有流媒体</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="79"/>
        <location filename="../../mainwindow.ui" line="144"/>
        <source>Applications</source>
        <translation>应用程序</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="84"/>
        <location filename="../../mainwindow.ui" line="149"/>
        <source>Virtual Streams</source>
        <translation>虚拟流媒体</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="93"/>
        <source>&amp;Recording</source>
        <translation>录音(&amp;R)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="120"/>
        <source>&lt;i&gt;No application is currently recording audio.&lt;/i&gt;</source>
        <translation>&lt;i&gt;没有程序正在录音。&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="158"/>
        <source>&amp;Output Devices</source>
        <translation>输出设备(&amp;O)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="185"/>
        <source>&lt;i&gt;No output devices available&lt;/i&gt;</source>
        <translation>&lt;i&gt;没有可用的输出设备&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="204"/>
        <source>All Output Devices</source>
        <translation>所有输出设备</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="209"/>
        <source>Hardware Output Devices</source>
        <translation>硬件输出设备</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="214"/>
        <source>Virtual Output Devices</source>
        <translation>虚拟输出设备</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="223"/>
        <source>&amp;Input Devices</source>
        <translation>输入设备(&amp;I)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="250"/>
        <source>&lt;i&gt;No input devices available&lt;/i&gt;</source>
        <translation>&lt;i&gt;没有可用的输入设备&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="269"/>
        <source>All Input Devices</source>
        <translation>所有输入设备</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="274"/>
        <source>All Except Monitors</source>
        <translation>除监视器外所有</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="279"/>
        <source>Hardware Input Devices</source>
        <translation>硬件输入设备</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="284"/>
        <source>Virtual Input Devices</source>
        <translation>虚拟输入设备</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="289"/>
        <source>Monitors</source>
        <translation>监视器</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="298"/>
        <source>&amp;Configuration</source>
        <translation>配置（&amp;C）</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="325"/>
        <source>&lt;i&gt;No cards available for configuration&lt;/i&gt;</source>
        <translation>&lt;i&gt;没有可用来配置的声卡&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="336"/>
        <source>Show volume meters</source>
        <translation>显示音量表</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="347"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="159"/>
        <source> (plugged in)</source>
        <translation> （已插入）</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="163"/>
        <location filename="../../mainwindow.cc" line="257"/>
        <source> (unavailable)</source>
        <translation> （不可用）</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="165"/>
        <location filename="../../mainwindow.cc" line="254"/>
        <source> (unplugged)</source>
        <translation> （已拔出）</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="386"/>
        <source>Failed to read data from stream</source>
        <translation>无法从流媒体中读取数据</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="430"/>
        <source>Peak detect</source>
        <translation>尖峰探测</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="431"/>
        <source>Failed to create monitoring stream</source>
        <translation>无法创建监视流媒体</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="446"/>
        <source>Failed to connect monitoring stream</source>
        <translation>无法连接到监视流媒体</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="585"/>
        <source>Ignoring sink-input due to it being designated as an event and thus handled by the Event widget</source>
        <translation>忽略漏级输入，因为它被设计为事件，且由事件小部件掌管</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="757"/>
        <source>System Sounds</source>
        <translation>系统声音</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="1088"/>
        <source>Establishing connection to PulseAudio. Please wait...</source>
        <translation>正在与 PulseAudio 建立连接，请稍候……</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../pavucontrol.cc" line="67"/>
        <source>Error</source>
        <translation>错误</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="88"/>
        <source>Card callback failure</source>
        <translation>声卡回叫失败</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="111"/>
        <source>Sink callback failure</source>
        <translation>Sink 回叫失败</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="134"/>
        <source>Source callback failure</source>
        <translation>源回叫失败</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="153"/>
        <source>Sink input callback failure</source>
        <translation>Sink 输入回叫失败</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="172"/>
        <source>Source output callback failure</source>
        <translation>源输出回叫失败</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="212"/>
        <source>Client callback failure</source>
        <translation>客户端回叫失败</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="228"/>
        <source>Server info callback failure</source>
        <translation>服务器信息回叫失败</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="246"/>
        <location filename="../../pavucontrol.cc" line="543"/>
        <source>Failed to initialize stream_restore extension: %s</source>
        <translation>无法初始化 stream_restore 扩展：%s</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="264"/>
        <source>pa_ext_stream_restore_read() failed</source>
        <translation>pa_ext_stream_restore_read() 失败</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="282"/>
        <location filename="../../pavucontrol.cc" line="557"/>
        <source>Failed to initialize device restore extension: %s</source>
        <translation>初始化设备恢复扩展失败：%s</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="303"/>
        <source>pa_ext_device_restore_read_sink_formats() failed</source>
        <translation>pa_ext_device_restore_read_sink_formats() 失败</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="321"/>
        <location filename="../../pavucontrol.cc" line="570"/>
        <source>Failed to initialize device manager extension: %s</source>
        <translation>初始化设备管理器扩展失败：%s</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="340"/>
        <source>pa_ext_device_manager_read() failed</source>
        <translation>pa_ext_device_manager_read() 失败</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="357"/>
        <source>pa_context_get_sink_info_by_index() failed</source>
        <translation>pa_context_get_sink_info_by_index() 失败</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="370"/>
        <source>pa_context_get_source_info_by_index() failed</source>
        <translation>pa_context_get_source_info_by_index() 失败</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="383"/>
        <location filename="../../pavucontrol.cc" line="396"/>
        <source>pa_context_get_sink_input_info() failed</source>
        <translation>pa_context_get_sink_input_info() 失败</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="409"/>
        <source>pa_context_get_client_info() failed</source>
        <translation>pa_context_get_client_info() 失败</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="419"/>
        <location filename="../../pavucontrol.cc" line="484"/>
        <source>pa_context_get_server_info() failed</source>
        <translation>pa_context_get_server_info() 失败</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="432"/>
        <source>pa_context_get_card_info_by_index() failed</source>
        <translation>pa_context_get_card_info_by_index() 失败</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="475"/>
        <source>pa_context_subscribe() failed</source>
        <translation>pa_context_subscribe() 失败</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="491"/>
        <source>pa_context_client_info_list() failed</source>
        <translation>pa_context_client_info_list() 失败</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="498"/>
        <source>pa_context_get_card_info_list() failed</source>
        <translation>pa_context_get_card_info_list() 失败</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="505"/>
        <source>pa_context_get_sink_info_list() failed</source>
        <translation>pa_context_get_sink_info_list() 失败</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="512"/>
        <source>pa_context_get_source_info_list() failed</source>
        <translation>pa_context_get_source_info_list() 失败</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="519"/>
        <source>pa_context_get_sink_input_info_list() failed</source>
        <translation>pa_context_get_sink_input_info_list() 失败</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="526"/>
        <source>pa_context_get_source_output_info_list() failed</source>
        <translation>pa_context_get_source_output_info_list() 失败</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="585"/>
        <location filename="../../pavucontrol.cc" line="636"/>
        <source>Connection failed, attempting reconnect</source>
        <translation>连接失败，尝试重新连接</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="608"/>
        <location filename="../../pavucontrol.cc" line="668"/>
        <source>PulseAudio Volume Control</source>
        <translation>PulseAudio 音量控制</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="623"/>
        <source>Connection to PulseAudio failed. Automatic retry in 5s

In this case this is likely because PULSE_SERVER in the Environment/X11 Root Window Properties
or default-server in client.conf is misconfigured.
This situation can also arrise when PulseAudio crashed and left stale details in the X11 Root Window.
If this is the case, then PulseAudio should autospawn again, or if this is not configured you should
run start-pulseaudio-x11 manually.</source>
        <translation>连接 PulseAudio 失败。5秒内自动重试

出现这种情况可能是因为 X11 根窗口属性中的 PULSE_SERVER 或者 client.conf 中的默认服务器配置不当。
这种情况也有可能在 PulseAudio 崩溃并在 X11 根窗口中留下陈旧明细时出现。
若如此，则 PulseAudio 应自动重启，否则您应手动运行 start-pulseaudio-x11 manually。</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="676"/>
        <source>Select a specific tab on load.</source>
        <translation>选择加载特定标签。</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="679"/>
        <source>Retry forever if pa quits (every 5 seconds).</source>
        <translation>如果 pa 退出，永远尝试（每 5 秒）。</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="682"/>
        <source>Maximize the window.</source>
        <translation>最大化窗口。</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="707"/>
        <source>Fatal Error: Unable to connect to PulseAudio</source>
        <translation>严重错误：无法连接 PulseAudio</translation>
    </message>
</context>
<context>
    <name>RoleWidget</name>
    <message>
        <location filename="../../rolewidget.cc" line="59"/>
        <source>pa_ext_stream_restore_write() failed</source>
        <translation>pa_ext_stream_restore_write() 失败</translation>
    </message>
</context>
<context>
    <name>SinkInputWidget</name>
    <message>
        <location filename="../../sinkinputwidget.cc" line="36"/>
        <source>on</source>
        <translation>开</translation>
    </message>
    <message>
        <location filename="../../sinkinputwidget.cc" line="39"/>
        <source>Terminate Playback</source>
        <translation>结束回放</translation>
    </message>
    <message>
        <location filename="../../sinkinputwidget.cc" line="53"/>
        <source>Unknown output</source>
        <translation>未知输出</translation>
    </message>
    <message>
        <location filename="../../sinkinputwidget.cc" line="64"/>
        <source>pa_context_set_sink_input_volume() failed</source>
        <translation>pa_context_set_sink_input_volume() 失败</translation>
    </message>
    <message>
        <location filename="../../sinkinputwidget.cc" line="79"/>
        <source>pa_context_set_sink_input_mute() failed</source>
        <translation>pa_context_set_sink_input_mute() 失败</translation>
    </message>
    <message>
        <location filename="../../sinkinputwidget.cc" line="89"/>
        <source>pa_context_kill_sink_input() failed</source>
        <translation>pa_context_kill_sink_input() 失败</translation>
    </message>
    <message>
        <location filename="../../sinkinputwidget.cc" line="114"/>
        <source>pa_context_move_sink_input_by_index() failed</source>
        <translation>pa_context_move_sink_input_by_index() 失败</translation>
    </message>
</context>
<context>
    <name>SinkWidget</name>
    <message>
        <location filename="../../sinkwidget.cc" line="81"/>
        <source>pa_context_set_sink_volume_by_index() failed</source>
        <translation>pa_context_set_sink_volume_by_index() 失败</translation>
    </message>
    <message>
        <source>Volume Control Feedback Sound</source>
        <translation type="vanished">音量控制反馈声音</translation>
    </message>
    <message>
        <location filename="../../sinkwidget.cc" line="96"/>
        <source>pa_context_set_sink_mute_by_index() failed</source>
        <translation>pa_context_set_sink_mute_by_index() 失败</translation>
    </message>
    <message>
        <location filename="../../sinkwidget.cc" line="110"/>
        <source>pa_context_set_default_sink() failed</source>
        <translation>pa_context_set_default_sink() 失败</translation>
    </message>
    <message>
        <location filename="../../sinkwidget.cc" line="126"/>
        <source>pa_context_set_sink_port_by_index() failed</source>
        <translation>pa_context_set_sink_mute_by_index() 失败</translation>
    </message>
    <message>
        <location filename="../../sinkwidget.cc" line="166"/>
        <source>pa_ext_device_restore_save_sink_formats() failed</source>
        <translation>pa_ext_device_restore_save_sink_formats() 失败</translation>
    </message>
</context>
<context>
    <name>SourceOutputWidget</name>
    <message>
        <location filename="../../sourceoutputwidget.cc" line="36"/>
        <source>from</source>
        <translation>形式</translation>
    </message>
    <message>
        <location filename="../../sourceoutputwidget.cc" line="39"/>
        <source>Terminate Recording</source>
        <translation>结束录音</translation>
    </message>
    <message>
        <location filename="../../sourceoutputwidget.cc" line="60"/>
        <source>Unknown input</source>
        <translation>未知输出</translation>
    </message>
    <message>
        <location filename="../../sourceoutputwidget.cc" line="72"/>
        <source>pa_context_set_source_output_volume() failed</source>
        <translation>pa_context_set_source_output_volume() 失败</translation>
    </message>
    <message>
        <location filename="../../sourceoutputwidget.cc" line="87"/>
        <source>pa_context_set_source_output_mute() failed</source>
        <translation>pa_context_set_source_output_mute() 失败</translation>
    </message>
    <message>
        <location filename="../../sourceoutputwidget.cc" line="98"/>
        <source>pa_context_kill_source_output() failed</source>
        <translation>pa_context_kill_source_output() 失败</translation>
    </message>
    <message>
        <location filename="../../sourceoutputwidget.cc" line="125"/>
        <source>pa_context_move_source_output_by_index() failed</source>
        <translation>pa_context_move_source_output_by_index() 失败</translation>
    </message>
</context>
<context>
    <name>SourceWidget</name>
    <message>
        <location filename="../../sourcewidget.cc" line="35"/>
        <source>pa_context_set_source_volume_by_index() failed</source>
        <translation>pa_context_set_source_volume_by_index() 失败</translation>
    </message>
    <message>
        <location filename="../../sourcewidget.cc" line="50"/>
        <source>pa_context_set_source_mute_by_index() failed</source>
        <translation>pa_context_set_source_mute_by_index() 失败</translation>
    </message>
    <message>
        <location filename="../../sourcewidget.cc" line="64"/>
        <source>pa_context_set_default_source() failed</source>
        <translation>pa_context_set_default_source() 失败</translation>
    </message>
    <message>
        <location filename="../../sourcewidget.cc" line="80"/>
        <source>pa_context_set_source_port_by_index() failed</source>
        <translation>pa_context_set_source_mute_by_index() 失败</translation>
    </message>
</context>
<context>
    <name>StreamWidget</name>
    <message>
        <location filename="../../streamwidget.ui" line="14"/>
        <source>Form</source>
        <translation>形式</translation>
    </message>
    <message>
        <location filename="../../streamwidget.ui" line="32"/>
        <source>Device Title</source>
        <translation>设备标题</translation>
    </message>
    <message>
        <location filename="../../streamwidget.ui" line="52"/>
        <source>direction</source>
        <translation>方向</translation>
    </message>
    <message>
        <location filename="../../streamwidget.ui" line="59"/>
        <source>device</source>
        <translation>设备</translation>
    </message>
    <message>
        <location filename="../../streamwidget.ui" line="66"/>
        <source>Mute audio</source>
        <translation>静音</translation>
    </message>
    <message>
        <location filename="../../streamwidget.ui" line="79"/>
        <source>Lock channels together</source>
        <translation>同时设置声道</translation>
    </message>
    <message>
        <source>Device</source>
        <translation type="vanished">输入设备(&amp;I)</translation>
    </message>
    <message>
        <location filename="../../streamwidget.cc" line="34"/>
        <source>Terminate</source>
        <translation>结束</translation>
    </message>
</context>
</TS>
